==> adams-heatmap-0.4.4-test-sources.jar: adams/data/io/input/FloatMatrixHeatmapReaderTest.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * FloatMatrixHeatmapReaderTest.java
 * Copyright (C) 2013 University of Waikato, Hamilton, New Zealand
 */

package adams.data.io.input;

import junit.framework.Test;
import junit.framework.TestSuite;
import adams.env.Environment;

/**
 * Tests the adams.data.io.input.FloatMatrixHeatmapReader class. Run from commandline with: <p/>
 * java adams.data.io.input.FloatMatrixHeatmapReader
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 6887 $
 */
public class FloatMatrixHeatmapReaderTest
  extends AbstractHeatmapReaderTestCase {

  /**
   * Initializes the test.
   *
   * @param name	the name of the test
   */
  public FloatMatrixHeatmapReaderTest(String name) {
    super(name);
  }

  /**
   * Returns the filenames (without path) of the input data files to use
   * in the regression test.
   *
   * @return		the filenames
   */
  @Override
  protected String[] getRegressionInputFiles() {
    return new String[]{
	"simple.dat",
    };
  }

  /**
   * Returns the setups to use in the regression test.
   *
   * @return		the setups
   */
  @Override
  protected AbstractHeatmapReader[] getRegressionSetups() {
    FloatMatrixHeatmapReader[]	result;
    
    result    = new FloatMatrixHeatmapReader[1];
    result[0] = new FloatMatrixHeatmapReader();
    result[0].setWidth(4);
    result[0].setHeight(3);
    
    return result;
  }

  /**
   * Returns a test suite.
   *
   * @return		the test suite
   */
  public static Test suite() {
    return new TestSuite(FloatMatrixHeatmapReaderTest.class);
  }

  /**
   * Runs the test from commandline.
   *
   * @param args	ignored
   */
  public static void main(String[] args) {
    Environment.setEnvironmentClass(Environment.class);
    runTest(suite());
  }
}

==> adams-heatmap-16.12.1-test-sources.jar: adams/data/io/input/FloatMatrixHeatmapReaderTest.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * FloatMatrixHeatmapReaderTest.java
 * Copyright (C) 2013 University of Waikato, Hamilton, New Zealand
 */

package adams.data.io.input;

import junit.framework.Test;
import junit.framework.TestSuite;
import adams.env.Environment;

/**
 * Tests the adams.data.io.input.FloatMatrixHeatmapReader class. Run from commandline with: <br><br>
 * java adams.data.io.input.FloatMatrixHeatmapReader
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 10825 $
 */
public class FloatMatrixHeatmapReaderTest
  extends AbstractHeatmapReaderTestCase {

  /**
   * Initializes the test.
   *
   * @param name	the name of the test
   */
  public FloatMatrixHeatmapReaderTest(String name) {
    super(name);
  }

  /**
   * Returns the filenames (without path) of the input data files to use
   * in the regression test.
   *
   * @return		the filenames
   */
  @Override
  protected String[] getRegressionInputFiles() {
    return new String[]{
	"simple.dat",
    };
  }

  /**
   * Returns the setups to use in the regression test.
   *
   * @return		the setups
   */
  @Override
  protected AbstractHeatmapReader[] getRegressionSetups() {
    FloatMatrixHeatmapReader[]	result;
    
    result    = new FloatMatrixHeatmapReader[1];
    result[0] = new FloatMatrixHeatmapReader();
    result[0].setWidth(4);
    result[0].setHeight(3);
    
    return result;
  }

  /**
   * Returns a test suite.
   *
   * @return		the test suite
   */
  public static Test suite() {
    return new TestSuite(FloatMatrixHeatmapReaderTest.class);
  }

  /**
   * Runs the test from commandline.
   *
   * @param args	ignored
   */
  public static void main(String[] args) {
    Environment.setEnvironmentClass(Environment.class);
    runTest(suite());
  }
}
